==> gdal_2.2.3+dfsg.orig.tar.xz: gdal-2.2.3/ogr/ogrsf_frmts/generic/ogr_attrind.cpp <==
/******************************************************************************
 *
 * Project:  OpenGIS Simple Features Reference Implementation
 * Purpose:  Implementation of OGRLayerAttrIndex and OGRAttrIndex base classes.
 * Author:   Frank Warmerdam, warmerdam@pobox.com
 *
 ******************************************************************************
 * Copyright (c) 2003, Frank Warmerdam
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 ****************************************************************************/

#include "ogr_attrind.h"
#include "cpl_conv.h"

CPL_CVSID("$Id: ogr_attrind.cpp 35172 2016-08-21 20:33:08Z goatbar $");

//! @cond Doxygen_Suppress

/************************************************************************/
/* ==================================================================== */
/*                           OGRLayerAttrIndex                          */
/* ==================================================================== */
/************************************************************************/

/************************************************************************/
/*                         OGRLayerAttrIndex()                          */
/************************************************************************/

OGRLayerAttrIndex::OGRLayerAttrIndex() :
    poLayer(NULL),
    pszIndexPath(NULL)
{}

/************************************************************************/
/*                         ~OGRLayerAttrIndex()                         */
/************************************************************************/

OGRLayerAttrIndex::~OGRLayerAttrIndex()

{
    CPLFree( pszIndexPath );
    pszIndexPath = NULL;
}

/************************************************************************/
/* ==================================================================== */
/*                             OGRAttrIndex                             */
/* ==================================================================== */
/************************************************************************/

/************************************************************************/
/*                            OGRAttrIndex()                            */
/************************************************************************/

OGRAttrIndex::OGRAttrIndex() {}

/************************************************************************/
/*                           ~OGRAttrIndex()                            */
/************************************************************************/

OGRAttrIndex::~OGRAttrIndex() {}

//! @endcond

==> gdal_3.2.2+dfsg.orig.tar.xz: gdal-3.2.2/ogr/ogrsf_frmts/generic/ogr_attrind.cpp <==
/******************************************************************************
 *
 * Project:  OpenGIS Simple Features Reference Implementation
 * Purpose:  Implementation of OGRLayerAttrIndex and OGRAttrIndex base classes.
 * Author:   Frank Warmerdam, warmerdam@pobox.com
 *
 ******************************************************************************
 * Copyright (c) 2003, Frank Warmerdam
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 ****************************************************************************/

#include "ogr_attrind.h"
#include "cpl_conv.h"

CPL_CVSID("$Id: ogr_attrind.cpp 7e07230bbff24eb333608de4dbd460b7312839d0 2017-12-11 19:08:47Z Even Rouault $")

//! @cond Doxygen_Suppress

/************************************************************************/
/* ==================================================================== */
/*                           OGRLayerAttrIndex                          */
/* ==================================================================== */
/************************************************************************/

/************************************************************************/
/*                         OGRLayerAttrIndex()                          */
/************************************************************************/

OGRLayerAttrIndex::OGRLayerAttrIndex() :
    poLayer(nullptr),
    pszIndexPath(nullptr)
{}

/************************************************************************/
/*                         ~OGRLayerAttrIndex()                         */
/************************************************************************/

OGRLayerAttrIndex::~OGRLayerAttrIndex()

{
    CPLFree( pszIndexPath );
    pszIndexPath = nullptr;
}

/************************************************************************/
/* ==================================================================== */
/*                             OGRAttrIndex                             */
/* ==================================================================== */
/************************************************************************/

/************************************************************************/
/*                            OGRAttrIndex()                            */
/************************************************************************/

OGRAttrIndex::OGRAttrIndex() {}

/************************************************************************/
/*                           ~OGRAttrIndex()                            */
/************************************************************************/

OGRAttrIndex::~OGRAttrIndex() {}

//! @endcond
